bidict
======
 
Efficient, Pythonic bidirectional map implementation and related functionality.

.. image:: https://raw.githubusercontent.com/jab/bidict/master/_static/logo-256.png
    :target: https://bidict.readthedocs.io/
    :alt: bidict logo

.. image:: https://raw.githubusercontent.com/jab/bidict/master/_static/support-on-gumroad.png
    :target: https://gumroad.com/l/bidict
    :alt: Support bidict


Status
------

.. Hide downloads badge pending https://github.com/badges/shields/issues/716
.. .. image:: https://img.shields.io/pypi/dm/bidict.svg
..     :target: https://pypi.python.org/pypi/bidict
..     :alt: Downloads per month

.. image:: https://img.shields.io/pypi/v/bidict.svg
    :target: https://pypi.python.org/pypi/bidict
    :alt: Latest release

.. image:: https://img.shields.io/badge/versionEye-follow-brightgreen.svg
    :target: https://www.versioneye.com/python/bidict
    :alt: Follow on VersionEye

.. image:: https://readthedocs.org/projects/bidict/badge/?version=master
    :target: https://bidict.readthedocs.io/en/master/
    :alt: Documentation

.. image:: https://travis-ci.org/jab/bidict.svg?branch=master
    :target: https://travis-ci.org/jab/bidict
    :alt: Build status

.. image:: https://coveralls.io/repos/jab/bidict/badge.svg?branch=master
    :target: https://coveralls.io/github/jab/bidict
    :alt: Test coverage

.. image:: https://img.shields.io/pypi/pyversions/bidict.svg
    :target: https://pypi.python.org/pypi/bidict
    :alt: Supported Python versions

.. image:: https://img.shields.io/pypi/implementation/bidict.svg
    :target: https://pypi.python.org/pypi/bidict
    :alt: Supported Python implementations

.. image:: https://img.shields.io/pypi/l/bidict.svg
    :target: https://raw.githubusercontent.com/jab/bidict/master/LICENSE
    :alt: License

.. image:: https://badges.gitter.im/join%20chat.svg
    :target: https://gitter.im/jab/bidict
    :alt: Chat

The bidict codebase is mature, well-tested, and well-reviewed.
If you have a question or find an issue,
please don't hesitate to
`ask in the chat room <https://gitter.im/jab/bidict>`_,
`file an issue <https://github.com/jab/bidict/issues/new>`_,
or
`submit a pull request <contributing>`_.


Installation
------------

``pip install bidict``


Usage
-----

For usage documentation, please start at the Introduction
and proceed from there.

`bidict.readthedocs.io <https://bidict.readthedocs.io>`_
++++++++++++++++++++++++++++++++++++++++++++++++++++++++

*In case you're reading this on GitHub, PyPI, in your code editor,
or in some other place that can't render/link the full docs properly,
you can find the bidict documentation on Read the Docs at:*

    `<https://bidict.readthedocs.io>`_

*Note that multiple versions of the documentation are published there,
and by default you will be taken to the version built from the master branch.
You can choose different versions from the pop-up menu in the lower-right.*

You can also build the docs yourself by running ``make html``
from the ``docs`` directory
(requires `Sphinx <https://pypi.python.org/pypi/Sphinx>`_).


Contributing
------------

Contributions are gratefully received!
For information about contributing,
please see CONTRIBUTING.rst
(`<https://bidict.readthedocs.io/contributing.html>`_).


Changelog
---------

For a history of notable changes to bidict,
check out CHANGELOG.rst
(`<https://bidict.readthedocs.io/changelog.html>`_).
